@@ -12,7 +12,7 @@
 ##############################################################################
 """ Unit test layers.
 
-$Id: testing.py 110663 2010-04-08 15:59:45Z tseaver $
+$Id: testing.py 113192 2010-06-06 13:40:29Z hannosch $
 """
 
 from Testing import ZopeTestCase
@@ -20,11 +20,16 @@ ZopeTestCase.installProduct('ZCTextIndex', 1)
 ZopeTestCase.installProduct('CMFCore', 1)
 
 import transaction
-from Products.Five import zcml
 
 from Products.CMFCore.testing import FunctionalZCMLLayer
 from Products.CMFDefault.factory import addConfiguredSite
 
+# BBB for Zope 2.12
+try:
+    from Zope2.App import zcml
+except ImportError:
+    from Products.Five import zcml
+
 
 class FunctionalLayer(FunctionalZCMLLayer):
 
